<?php
add_action( 'after_setup_theme', 'halloween_setup' );
function halloween_setup() {
load_theme_textdomain( 'halloween', get_template_directory() . '/languages' );
add_theme_support( 'title-tag' );
add_theme_support( 'custom-logo' );
add_theme_support( 'custom-header' );
add_theme_support( 'custom-background' );
add_theme_support( 'post-thumbnails' );
add_theme_support( 'responsive-embeds' );
add_theme_support( 'automatic-feed-links' );
add_theme_support( 'html5', array( 'search-form', 'navigation-widgets' ) );
add_theme_support( 'woocommerce' );
global $content_width;
if ( !isset( $content_width ) ) { $content_width = 1920; }
register_nav_menus( array( 'main-menu' => esc_html__( 'Main Menu', 'halloween' ) ) );
}
add_action( 'wp_enqueue_scripts', 'halloween_enqueue' );
function halloween_enqueue() {
wp_enqueue_style( 'halloween-style', get_stylesheet_uri() );
wp_enqueue_script( 'jquery' );
wp_register_script( 'halloween-videos', get_template_directory_uri() . '/js/videos.js' );
wp_enqueue_script( 'halloween-videos' );
wp_add_inline_script( 'halloween-videos', 'jQuery(document).ready(function($){$("body").vids();});' );
}
add_action( 'wp_footer', 'halloween_footer' );
function halloween_footer() {
?>
<script>
jQuery(document).ready(function($) {
$(".menu-toggle").on("keypress click", function(e) {
if (e.which == 13 || e.type === "click") {
e.preventDefault();
$("#menu").toggleClass("toggled");
}
});
$(document).keyup(function(e) {
if (e.keyCode == 27) {
if ($("#menu").hasClass("toggled")) {
$("#menu").toggleClass("toggled");
}
}
});
$("img.no-logo").each(function() {
var alt = $(this).attr("alt");
$(this).replaceWith(alt);
});
});
</script>
<?php
}
add_action( 'admin_notices', 'halloween_notice' );
function halloween_notice() {
$user_id = get_current_user_id();
$admin_url = ( isset( $_SERVER['HTTPS'] ) && $_SERVER['HTTPS'] === 'on' ? 'https' : 'http' ) . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
$param = ( count( $_GET ) ) ? '&' : '?';
if ( !get_user_meta( $user_id, 'halloween_notice_dismissed_2' ) && current_user_can( 'manage_options' ) )
echo '<div class="notice notice-info"><p><a href="' . esc_url( $admin_url ), esc_html( $param ) . 'dismiss" class="alignright" style="text-decoration:none"><big>' . esc_html__( 'Ⓧ', 'halloween' ) . '</big></a>' . wp_kses_post( __( '<big><strong>🎃 Happy Halloween!</strong> | </big>', 'halloween' ) ) . 'Help support us by <a href="https://halloweenlove.com/donate" class="button-primary" target="_blank">' . esc_html__( 'Making a Donation', 'halloween' ) . '</a></p></div>';
}
add_action( 'admin_init', 'halloween_notice_dismissed' );
function halloween_notice_dismissed() {
$user_id = get_current_user_id();
if ( isset( $_GET['dismiss'] ) )
add_user_meta( $user_id, 'halloween_notice_dismissed_2', 'true', true );
}
add_filter( 'document_title_separator', 'halloween_document_title_separator' );
function halloween_document_title_separator( $sep ) {
$sep = esc_html( '|' );
return $sep;
}
add_filter( 'the_title', 'halloween_title' );
function halloween_title( $title ) {
if ( $title == '' ) {
return esc_html( '...' );
} else {
return wp_kses_post( $title );
}
}
function halloween_schema_type() {
$schema = 'https://schema.org/';
if ( is_single() ) {
$type = "Article";
} elseif ( is_author() ) {
$type = 'ProfilePage';
} elseif ( is_search() ) {
$type = 'SearchResultsPage';
} else {
$type = 'WebPage';
}
echo 'itemscope itemtype="' . esc_url( $schema ) . esc_attr( $type ) . '"';
}
add_filter( 'nav_menu_link_attributes', 'halloween_schema_url', 10 );
function halloween_schema_url( $atts ) {
$atts['itemprop'] = 'url';
return $atts;
}
if ( !function_exists( 'halloween_wp_body_open' ) ) {
function halloween_wp_body_open() {
do_action( 'wp_body_open' );
}
}
add_action( 'wp_body_open', 'halloween_skip_link', 5 );
function halloween_skip_link() {
echo '<a href="#content" class="skip-link screen-reader-text">' . esc_html__( 'Skip to the content', 'halloween' ) . '</a>';
}
add_filter( 'the_content_more_link', 'halloween_read_more_link' );
function halloween_read_more_link() {
if ( !is_admin() ) {
return ' <a href="' . esc_url( get_permalink() ) . '" class="more-link">...</a>';
}
}
add_filter( 'excerpt_more', 'halloween_excerpt_read_more_link' );
function halloween_excerpt_read_more_link( $more ) {
if ( !is_admin() ) {
global $post;
return ' <a href="' . esc_url( get_permalink( $post->ID ) ) . '" class="more-link">...</a>';
}
}
add_filter( 'big_image_size_threshold', '__return_false' );
add_filter( 'intermediate_image_sizes_advanced', 'halloween_image_insert_override' );
function halloween_image_insert_override( $sizes ) {
unset( $sizes['medium_large'] );
unset( $sizes['1536x1536'] );
unset( $sizes['2048x2048'] );
return $sizes;
}
add_action( 'widgets_init', 'halloween_widgets_init' );
function halloween_widgets_init() {
register_sidebar( array(
'name' => esc_html__( 'Sidebar Widget Area', 'halloween' ),
'id' => 'primary-widget-area',
'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
'after_widget' => '</li>',
'before_title' => '<h3 class="widget-title">',
'after_title' => '</h3>',
) );
}
add_action( 'wp_head', 'halloween_pingback_header' );
function halloween_pingback_header() {
if ( is_singular() && pings_open() ) {
printf( '<link rel="pingback" href="%s" />' . "\n", esc_url( get_bloginfo( 'pingback_url' ) ) );
}
}
add_action( 'comment_form_before', 'halloween_enqueue_comment_reply_script' );
function halloween_enqueue_comment_reply_script() {
if ( get_option( 'thread_comments' ) ) {
wp_enqueue_script( 'comment-reply' );
}
}
function halloween_custom_pings( $comment ) {
?>
<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>"><?php echo comment_author_link(); ?></li>
<?php
}
add_filter( 'get_comments_number', 'halloween_comment_count', 0 );
function halloween_comment_count( $count ) {
if ( !is_admin() ) {
global $id;
$get_comments = get_comments( 'status=approve&post_id=' . $id );
$comments_by_type = separate_comments( $get_comments );
return count( $comments_by_type['comment'] );
} else {
return $count;
}
}